@@ -1,4 +1,4 @@
 "print.varstabil" <-
 function(x, ...){
-  print(x[[1]])
+  print(x[[1]], ...)
 }
